#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_NINE_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_NINE_HPP_INCLUDED

#include <boost/simd/constant/include/constants/nine.hpp>

#endif
